# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/jupyter.ipynb (unless otherwise specified).

__all__ = ['displayHtml']

# Cell
def displayHtml(html):
    from IPython.display import display, HTML
    display(HTML(html))