# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/exception.ipynb (unless otherwise specified).

__all__ = ['errorString']

# Cell
import traceback

# Cell
def errorString():
  '''
  returns a string of the exception information
  '''
  return traceback.format_exc()