# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/jsonUtil.ipynb (unless otherwise specified).

__all__ = ['loadJson', 'saveJson']

# Cell
import json


def loadJson(path: str) -> dict:
    with open(path, "r") as f:
        return json.load(f)

# Cell
def saveJson(path: str, data: dict):
    with open(path, "w") as f:
        json.dump(data, f)
    return True